![desper logo](https://github.com/Ball-Man/pyglet-desper/blob/master/assets/desper-logo-raw.png?raw=true)

# Desper + Pyglet interoperation
Combine resource and logic management of [desper](https://github.com/Ball-Man/desper]) with [pyglet](https://github.com/pyglet/pyglet)'s rendering and media.

## Installation
Simple installation from PyPi (recommended):
```
pip install pyglet-desper
```
Or installation from master branch:
```
git clone https://github.com/Ball-Man/pyglet-desper
cd pyglet-desper
pip install .
```


## Project status
Docs and a user guide are in the making.
